
from antlr4.tree.Tree import TerminalNodeImpl

def parse_layer(tree, rule_names, parts, parents, indent = 0):
    """ 遍历树，保存叶子结点 """
    if tree.getText() == "<EOF>":
        return
    elif isinstance(tree, TerminalNodeImpl):
        # print("{0}TOKEN='{1}'".format("  " * indent, tree.getText()))
        # layer[indent].append(tree.getText())
        parts.append(tree.getText())
        parents.append(tree.getParent())
    elif tree.children is None:
        # print("none children", tree)
        return
    else:
        # print("{0}{1}".format("  " * indent, rule_names[tree.getRuleIndex()]))
        for child in tree.children:
            parse_layer(child, rule_names, parts, parents, indent + 1)


import os,sys
PROJ_DIR="/Users/qing/Library/Mobile Documents/com~apple~CloudDocs/workspace/Code/qdls"
sys.path.append(PROJ_DIR)

def test_syntax():
    from src.qdls.gql.sparql.utils.syntax import syntax_check

    # s1 = "select ?x {?e ?p 'asd'}"
    s = "SELECT DISTINCT?qpv WHERE {?e_1 <pred:name> \"Mrs. Miniver\".?e_2 <pred:name> \"Academy Award for Best Writing, Adapted Screenplay\".?e_1 <award_received>?e_2. [ <pred:fact_h>?e_1 ; <pred:fact_r> <award_received> ; <pred:fact_t>?e_2 ] <winner>?qpv.  }"

    flag, tree, parser = syntax_check(s)

    print(flag)
    print(type(tree))
    print("error msg:", tree)

def test_config():
    import omegaconf

    config = omegaconf.OmegaConf.load("example_config.yaml")
    print(config)
    print(type(config))
    from src.qdls.utils import config2dict, print_config
    d = config2dict(config)
    print(d)
    print_config(config, 'test pc')


if __name__ == '__main__':
    test_config()




from pygments.token import *
from antlr4.tree.Tree import TerminalNodeImpl
from antlr4 import InputStream, CommonTokenStream

from ..grammar.SparqlParser import SparqlParser
from ..grammar.SparqlLexer import SparqlLexer

from ...utils import parse_layer

def parse_sparql(sparql, tree_only=False):
    """ 返回输入sparql语句的AST树 
        AST 树、序列化的树
        便利后得到的 每个token 及其对应的父节点
    """
    input_stream = InputStream(sparql)
    # print(input_stream)
    lexer = SparqlLexer(input_stream)
    stream = CommonTokenStream(lexer)
    parser = SparqlParser(stream)
    tree = parser.query()
    tree.toStringTree()
    if tree_only:
        return tree, parser  
        
    parts, parents = [], []
    # print(tree)
    # traverse(tree, parser.ruleNames)
    parse_layer(tree, parser.ruleNames, parts, parents)
    print("after parsing", tree)
    for token, par in zip(parts, parents):
        print(token, "\t", par)
    s = tree.toStringTree(recog=parser)
    return tree, s, parts, parents 